diff --git a/doc/src/sgml/installation.sgml b/doc/src/sgml/installation.sgml
index ebdb5b3bc2d..523dba03b5b 100644
--- a/doc/src/sgml/installation.sgml
+++ b/doc/src/sgml/installation.sgml
@@ -2463,12 +2463,7 @@ ninja install
       <listitem>
        <para>
         Build with support for GSSAPI authentication. MIT Kerberos is required
-        to be installed for GSSAPI.  On many systems, the GSSAPI system (a part
-        of the MIT Kerberos installation) is not installed in a location
-        that is searched by default (e.g., <filename>/usr/include</filename>,
-        <filename>/usr/lib</filename>).  In
-        those cases, PostgreSQL will query <command>pkg-config</command> to
-        detect the required compiler and linker options.  Defaults to auto.
+        to be installed for GSSAPI.  Defaults to auto.
         <filename>meson configure</filename> will check for the required
         header files and libraries to make sure that your GSSAPI installation
         is sufficient before proceeding.
@@ -2589,12 +2584,6 @@ ninja install
         Build with libxml2, enabling SQL/XML support.  Defaults to
         auto. Libxml2 version 2.6.23 or later is required for this feature.
        </para>
-
-       <para>
-        To use a libxml2 installation that is in an unusual location, you
-        can set <command>pkg-config</command>-related environment
-        variables (see its documentation).
-       </para>
       </listitem>
      </varlistentry>
 
@@ -3174,6 +3163,50 @@ ninja install
    &targets-meson;
   </sect2>
 
+  <sect2 id="use-unusual-location-libraries-meson">
+   <title>Steps to use libraries installed in an unusual location</title>
+
+   <para>
+    PostgreSQL will query pkg-config to detect the required compiler and linker options.
+    To use modules installed in an unusual location, set pkg-config-related
+    environment variables (see its documentation). For example, if you want to add
+    the library to the PostgreSQL build, add the directory where the .pc file resides
+    to PKG_CONFIG_PATH.
+
+    Sample procedures to include libraries for PostgreSQL build are as follows:
+   </para>
+   
+    <procedure>
+    <step id="sample-build-library">
+     <title>Building and Installation library</title>
+     <para>
+      Check the path where the .pc file (e.g.libxml-2.0.pc) is created.
+      Many libraries create the .pc files when built using vcpkg.
+      You might want to create the .pc file manually.
+     </para>
+    </step>
+    <step id="sample-add-PKG_CONFIG_PATH">
+     <title>Add path to .pc directory to PKG_CONFIG_PATH</title>
+     <para>
+      PKG_CONFIG_PATH is the list of directories separated by PATH separator
+       ( ; in Windows, : in Unix). 
+     </para>
+    </step>
+    <step id="sample-build-meson">
+     <title>Building and Installation PostgreSQL with Meson</title>
+     <para>
+<screen>
+<userinput>meson setup build</userinput>
+</screen>
+      For some libraries (e.g. .pc file not created gettext), 
+      the path can be specified with the 
+      -Dextra_include_dirs, -Dextra_lib_dirs option.
+     </para>
+    </step>
+    </procedure>
+   
+  </sect2>
+
  </sect1>
 
  <sect1 id="install-post">
